#! /usr/bin/env python
# -*- coding: utf-8 -*-

####################
# IFTTT action plugin for Indigo 6
#
# Developed by Jonathan Draper, cribbing heavily from Chadio's Pushover plugin
####################

import httplib, urllib, sys, os


class Plugin(indigo.PluginBase):
    def __init__(self, pluginId, pluginDisplayName, pluginVersion, pluginPrefs):
        indigo.PluginBase.__init__(self, pluginId, pluginDisplayName, pluginVersion, pluginPrefs)

        self.debug = True

    def __del__(self):
        indigo.PluginBase.__del__(self)


    def startup(self):
        self.debugLog(u"Startup")

    def shutdown(self):
        self.debugLog(u"Shutdown")

    ########################################
    # actions
    ########################################
    def send(self, pluginAction):
        parameters = {}

        try:
            token = self.pluginPrefs["applicationapikey"]

            if "ifttttoken" in pluginAction.props and pluginAction.props["ifttttoken"]:
                token = pluginAction.props["ifttttoken"]

            if not token:
                raise Exception

            # Mandatory
            parameters["token"] = token
        except:
            self.errorLog(u"Mandatory API key not set")

            return

        try:
            event = u"%s" % pluginAction.props["txtevent"]
        
            while "%%" in event:
                event = self.substitute(event)
            
            # Mandatory
            parameters["event"] = event
        except:
            self.errorLog(u"Mandatory event name not set")
            
            return

        if "txtvalue1" in pluginAction.props and pluginAction.props["txtvalue1"]:
            value1 = u"%s" % pluginAction.props["txtvalue1"]

            while "%%" in value1:
                value1 = self.substitute(value1)

            # Optional
            parameters["value1"] = value1

        if "txtvalue2" in pluginAction.props and pluginAction.props["txtvalue2"]:
            value2 = u"%s" % pluginAction.props["txtvalue2"]
        
            while "%%"  in value2:
                value2 = self.substitute(value2)
            
            # Optional
            parameters["value2"] = value2

        if "txtvalue3" in pluginAction.props and pluginAction.props["txtvalue3"]:
            value3 = u"%s" % pluginAction.props["txtvalue3"]
        
            while "%%"  in value3:
                value3 = self.substitute(value3)
            
            # Optional
            parameters["value3"] = value3

        conn = httplib.HTTPSConnection("maker.ifttt.com")
        conn.request(
            "POST",
            "/trigger/" + event + "/with/key/" + token,
            urllib.urlencode( parameters ),
            {"Content-type": "application/x-www-form-urlencoded"})

    def generateTokenList(self, filter="", valuesDict=None, typeId="", targetId=0):
        tokens = self.pluginPrefs["applicationapikey"]
        tokens = tokens.replace(" ", "")

        tokenArray = tokens.split(",")
        tokenList = []

        for token in tokenArray:
            if ":" in token:
                name, key = token.split(":")
            else:
                name = token
                key = token

            tokenList.append((key, name))

        return tokenList

    ########################################
    # Helper methods
    ########################################
    def integerValue(self, value):
        try:
            if isinstance(value, int):
                return int(value)
            elif isinstance(value, float):
                return int(float(value + 0.5))
            elif type(value) is bool:
                if value:
                    return 1
                else:
                    return 0
            elif type(value) is str:
                try:
                    return int(value)
                except ValueError:
                    return int(float(value + 0.5))
        except:
            pass

        return None
